beaconv1

package
v1.12.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 29, 2025 License: Apache-2.0 Imports: 18 Imported by: 0

Documentation

Overview

Code generated by protoc-gen-go-pulsar. DO NOT EDIT.

Code generated by protoc-gen-go-pulsar. DO NOT EDIT.

Code generated by protoc-gen-go-pulsar. DO NOT EDIT.

Code generated by protoc-gen-go-pulsar. DO NOT EDIT.

Index

Constants

const (
	Query_Params_FullMethodName          = "/mainchain.beacon.v1.Query/Params"
	Query_Beacon_FullMethodName          = "/mainchain.beacon.v1.Query/Beacon"
	Query_BeaconTimestamp_FullMethodName = "/mainchain.beacon.v1.Query/BeaconTimestamp"
	Query_BeaconsFiltered_FullMethodName = "/mainchain.beacon.v1.Query/BeaconsFiltered"
	Query_BeaconStorage_FullMethodName   = "/mainchain.beacon.v1.Query/BeaconStorage"
)
const (
	Msg_RegisterBeacon_FullMethodName             = "/mainchain.beacon.v1.Msg/RegisterBeacon"
	Msg_RecordBeaconTimestamp_FullMethodName      = "/mainchain.beacon.v1.Msg/RecordBeaconTimestamp"
	Msg_PurchaseBeaconStateStorage_FullMethodName = "/mainchain.beacon.v1.Msg/PurchaseBeaconStateStorage"
	Msg_UpdateParams_FullMethodName               = "/mainchain.beacon.v1.Msg/UpdateParams"
)

Variables

var File_mainchain_beacon_v1_beacon_proto protoreflect.FileDescriptor
var File_mainchain_beacon_v1_genesis_proto protoreflect.FileDescriptor
var File_mainchain_beacon_v1_query_proto protoreflect.FileDescriptor
var File_mainchain_beacon_v1_tx_proto protoreflect.FileDescriptor
var Msg_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "mainchain.beacon.v1.Msg",
	HandlerType: (*MsgServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "RegisterBeacon",
			Handler:    _Msg_RegisterBeacon_Handler,
		},
		{
			MethodName: "RecordBeaconTimestamp",
			Handler:    _Msg_RecordBeaconTimestamp_Handler,
		},
		{
			MethodName: "PurchaseBeaconStateStorage",
			Handler:    _Msg_PurchaseBeaconStateStorage_Handler,
		},
		{
			MethodName: "UpdateParams",
			Handler:    _Msg_UpdateParams_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "mainchain/beacon/v1/tx.proto",
}

Msg_ServiceDesc is the grpc.ServiceDesc for Msg service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var Query_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "mainchain.beacon.v1.Query",
	HandlerType: (*QueryServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Params",
			Handler:    _Query_Params_Handler,
		},
		{
			MethodName: "Beacon",
			Handler:    _Query_Beacon_Handler,
		},
		{
			MethodName: "BeaconTimestamp",
			Handler:    _Query_BeaconTimestamp_Handler,
		},
		{
			MethodName: "BeaconsFiltered",
			Handler:    _Query_BeaconsFiltered_Handler,
		},
		{
			MethodName: "BeaconStorage",
			Handler:    _Query_BeaconStorage_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "mainchain/beacon/v1/query.proto",
}

Query_ServiceDesc is the grpc.ServiceDesc for Query service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterMsgServer

func RegisterMsgServer(s grpc.ServiceRegistrar, srv MsgServer)

func RegisterQueryServer

func RegisterQueryServer(s grpc.ServiceRegistrar, srv QueryServer)

Types

type Beacon

type Beacon struct {

	// beacon_id is the id of the beacon
	BeaconId uint64 `protobuf:"varint,1,opt,name=beacon_id,json=beaconId,proto3" json:"beacon_id,omitempty"`
	// moniker is the readable id of the beacon
	Moniker string `protobuf:"bytes,2,opt,name=moniker,proto3" json:"moniker,omitempty"`
	// name is the human friendly name of the beacon
	Name string `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	// last_timestamp_id is the current highest recorded timestamp id for the beacon
	LastTimestampId uint64 `protobuf:"varint,4,opt,name=last_timestamp_id,json=lastTimestampId,proto3" json:"last_timestamp_id,omitempty"`
	// first_id_in_state is the lowest recorded timestamp id currently held in state for the beacon
	FirstIdInState uint64 `protobuf:"varint,5,opt,name=first_id_in_state,json=firstIdInState,proto3" json:"first_id_in_state,omitempty"`
	// num_in_state is the current number of timestamps stored in state for the beacon
	NumInState uint64 `protobuf:"varint,6,opt,name=num_in_state,json=numInState,proto3" json:"num_in_state,omitempty"`
	// reg_time is the unix epoch of the beacon's registration time
	RegTime uint64 `protobuf:"varint,7,opt,name=reg_time,json=regTime,proto3" json:"reg_time,omitempty"`
	// owner is the owner address of the beacon
	Owner string `protobuf:"bytes,8,opt,name=owner,proto3" json:"owner,omitempty"`
	// contains filtered or unexported fields
}

Beacon holds metadata about a registered beacon

func (*Beacon) Descriptor deprecated

func (*Beacon) Descriptor() ([]byte, []int)

Deprecated: Use Beacon.ProtoReflect.Descriptor instead.

func (*Beacon) GetBeaconId

func (x *Beacon) GetBeaconId() uint64

func (*Beacon) GetFirstIdInState

func (x *Beacon) GetFirstIdInState() uint64

func (*Beacon) GetLastTimestampId

func (x *Beacon) GetLastTimestampId() uint64

func (*Beacon) GetMoniker

func (x *Beacon) GetMoniker() string

func (*Beacon) GetName

func (x *Beacon) GetName() string

func (*Beacon) GetNumInState

func (x *Beacon) GetNumInState() uint64

func (*Beacon) GetOwner

func (x *Beacon) GetOwner() string

func (*Beacon) GetRegTime

func (x *Beacon) GetRegTime() uint64

func (*Beacon) ProtoMessage

func (*Beacon) ProtoMessage()

func (*Beacon) ProtoReflect

func (x *Beacon) ProtoReflect() protoreflect.Message

func (*Beacon) Reset

func (x *Beacon) Reset()

func (*Beacon) String

func (x *Beacon) String() string

type BeaconExport

type BeaconExport struct {
	Beacon       *Beacon                         `protobuf:"bytes,1,opt,name=beacon,proto3" json:"beacon,omitempty"`
	InStateLimit uint64                          `protobuf:"varint,2,opt,name=in_state_limit,json=inStateLimit,proto3" json:"in_state_limit,omitempty"`
	Timestamps   []*BeaconTimestampGenesisExport `protobuf:"bytes,3,rep,name=timestamps,proto3" json:"timestamps,omitempty"`
	// contains filtered or unexported fields
}

BeaconExport holds genesis export data for a beacon, including submitted timestamps

func (*BeaconExport) Descriptor deprecated

func (*BeaconExport) Descriptor() ([]byte, []int)

Deprecated: Use BeaconExport.ProtoReflect.Descriptor instead.

func (*BeaconExport) GetBeacon

func (x *BeaconExport) GetBeacon() *Beacon

func (*BeaconExport) GetInStateLimit

func (x *BeaconExport) GetInStateLimit() uint64

func (*BeaconExport) GetTimestamps

func (x *BeaconExport) GetTimestamps() []*BeaconTimestampGenesisExport

func (*BeaconExport) ProtoMessage

func (*BeaconExport) ProtoMessage()

func (*BeaconExport) ProtoReflect

func (x *BeaconExport) ProtoReflect() protoreflect.Message

func (*BeaconExport) Reset

func (x *BeaconExport) Reset()

func (*BeaconExport) String

func (x *BeaconExport) String() string

type BeaconStorageLimit

type BeaconStorageLimit struct {

	// beacon_id is the id of the beacon
	BeaconId uint64 `protobuf:"varint,1,opt,name=beacon_id,json=beaconId,proto3" json:"beacon_id,omitempty"`
	// in_state_limit is the current maximum number of timestmamps that will be held in state for the beacon
	InStateLimit uint64 `protobuf:"varint,2,opt,name=in_state_limit,json=inStateLimit,proto3" json:"in_state_limit,omitempty"`
	// contains filtered or unexported fields
}

BeaconStorageLimit holds tata about the beacon's current in-state storage limit

func (*BeaconStorageLimit) Descriptor deprecated

func (*BeaconStorageLimit) Descriptor() ([]byte, []int)

Deprecated: Use BeaconStorageLimit.ProtoReflect.Descriptor instead.

func (*BeaconStorageLimit) GetBeaconId

func (x *BeaconStorageLimit) GetBeaconId() uint64

func (*BeaconStorageLimit) GetInStateLimit

func (x *BeaconStorageLimit) GetInStateLimit() uint64

func (*BeaconStorageLimit) ProtoMessage

func (*BeaconStorageLimit) ProtoMessage()

func (*BeaconStorageLimit) ProtoReflect

func (x *BeaconStorageLimit) ProtoReflect() protoreflect.Message

func (*BeaconStorageLimit) Reset

func (x *BeaconStorageLimit) Reset()

func (*BeaconStorageLimit) String

func (x *BeaconStorageLimit) String() string

type BeaconTimestamp

type BeaconTimestamp struct {

	// timestamp_id is the id of the timestamp
	TimestampId uint64 `protobuf:"varint,1,opt,name=timestamp_id,json=timestampId,proto3" json:"timestamp_id,omitempty"`
	// submit_time is the unix epoch of the timestamp's record time
	SubmitTime uint64 `protobuf:"varint,2,opt,name=submit_time,json=submitTime,proto3" json:"submit_time,omitempty"`
	// hash is the actual data stored for the timestamp
	Hash string `protobuf:"bytes,3,opt,name=hash,proto3" json:"hash,omitempty"`
	// contains filtered or unexported fields
}

BeaconTimestamp holds each hash submitted to a registered beacon

func (*BeaconTimestamp) Descriptor deprecated

func (*BeaconTimestamp) Descriptor() ([]byte, []int)

Deprecated: Use BeaconTimestamp.ProtoReflect.Descriptor instead.

func (*BeaconTimestamp) GetHash

func (x *BeaconTimestamp) GetHash() string

func (*BeaconTimestamp) GetSubmitTime

func (x *BeaconTimestamp) GetSubmitTime() uint64

func (*BeaconTimestamp) GetTimestampId

func (x *BeaconTimestamp) GetTimestampId() uint64

func (*BeaconTimestamp) ProtoMessage

func (*BeaconTimestamp) ProtoMessage()

func (*BeaconTimestamp) ProtoReflect

func (x *BeaconTimestamp) ProtoReflect() protoreflect.Message

func (*BeaconTimestamp) Reset

func (x *BeaconTimestamp) Reset()

func (*BeaconTimestamp) String

func (x *BeaconTimestamp) String() string

type BeaconTimestampGenesisExport

type BeaconTimestampGenesisExport struct {
	Id uint64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	T  uint64 `protobuf:"varint,2,opt,name=t,proto3" json:"t,omitempty"`
	H  string `protobuf:"bytes,3,opt,name=h,proto3" json:"h,omitempty"`
	// contains filtered or unexported fields
}

BeaconTimestampGenesisExport is a trimmed version of BeaconTimestamp for genesis exports to conserve space

func (*BeaconTimestampGenesisExport) Descriptor deprecated

func (*BeaconTimestampGenesisExport) Descriptor() ([]byte, []int)

Deprecated: Use BeaconTimestampGenesisExport.ProtoReflect.Descriptor instead.

func (*BeaconTimestampGenesisExport) GetH

func (*BeaconTimestampGenesisExport) GetId

func (*BeaconTimestampGenesisExport) GetT

func (*BeaconTimestampGenesisExport) ProtoMessage

func (*BeaconTimestampGenesisExport) ProtoMessage()

func (*BeaconTimestampGenesisExport) ProtoReflect

func (*BeaconTimestampGenesisExport) Reset

func (x *BeaconTimestampGenesisExport) Reset()

func (*BeaconTimestampGenesisExport) String

type GenesisState

type GenesisState struct {

	// params defines all the parameters of the module.
	Params            *Params         `protobuf:"bytes,1,opt,name=params,proto3" json:"params,omitempty"`
	StartingBeaconId  uint64          `protobuf:"varint,2,opt,name=starting_beacon_id,json=startingBeaconId,proto3" json:"starting_beacon_id,omitempty"`
	RegisteredBeacons []*BeaconExport `protobuf:"bytes,3,rep,name=registered_beacons,json=registeredBeacons,proto3" json:"registered_beacons,omitempty"`
	// contains filtered or unexported fields
}

GenesisState defines the beacon module's genesis state.

func (*GenesisState) Descriptor deprecated

func (*GenesisState) Descriptor() ([]byte, []int)

Deprecated: Use GenesisState.ProtoReflect.Descriptor instead.

func (*GenesisState) GetParams

func (x *GenesisState) GetParams() *Params

func (*GenesisState) GetRegisteredBeacons

func (x *GenesisState) GetRegisteredBeacons() []*BeaconExport

func (*GenesisState) GetStartingBeaconId

func (x *GenesisState) GetStartingBeaconId() uint64

func (*GenesisState) ProtoMessage

func (*GenesisState) ProtoMessage()

func (*GenesisState) ProtoReflect

func (x *GenesisState) ProtoReflect() protoreflect.Message

func (*GenesisState) Reset

func (x *GenesisState) Reset()

func (*GenesisState) String

func (x *GenesisState) String() string

type MsgClient

type MsgClient interface {
	// RegisterBeacon defines a method to register a new beacon
	RegisterBeacon(ctx context.Context, in *MsgRegisterBeacon, opts ...grpc.CallOption) (*MsgRegisterBeaconResponse, error)
	// RecordBeaconTimestamp defines a method to record a timestamp for a registered beacon
	RecordBeaconTimestamp(ctx context.Context, in *MsgRecordBeaconTimestamp, opts ...grpc.CallOption) (*MsgRecordBeaconTimestampResponse, error)
	// PurchaseBeaconStateStorage defines the method to purchase more state storage
	PurchaseBeaconStateStorage(ctx context.Context, in *MsgPurchaseBeaconStateStorage, opts ...grpc.CallOption) (*MsgPurchaseBeaconStateStorageResponse, error)
	// UpdateParams defines an operation for updating the x/beacon module
	// parameters.
	// Since: cosmos-sdk 0.47
	UpdateParams(ctx context.Context, in *MsgUpdateParams, opts ...grpc.CallOption) (*MsgUpdateParamsResponse, error)
}

MsgClient is the client API for Msg service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewMsgClient

func NewMsgClient(cc grpc.ClientConnInterface) MsgClient

type MsgPurchaseBeaconStateStorage

type MsgPurchaseBeaconStateStorage struct {

	// beacon_id is the id of the beacon the storage is being purchased for
	BeaconId uint64 `protobuf:"varint,1,opt,name=beacon_id,json=beaconId,proto3" json:"beacon_id,omitempty"`
	// number is the number of state storage spaces to purchase
	Number uint64 `protobuf:"varint,2,opt,name=number,proto3" json:"number,omitempty"`
	// owner is the address of the owner of the beacon
	Owner string `protobuf:"bytes,3,opt,name=owner,proto3" json:"owner,omitempty"`
	// contains filtered or unexported fields
}

MsgPurchaseBeaconStateStorage represents a message to purchase more beacon storage

func (*MsgPurchaseBeaconStateStorage) Descriptor deprecated

func (*MsgPurchaseBeaconStateStorage) Descriptor() ([]byte, []int)

Deprecated: Use MsgPurchaseBeaconStateStorage.ProtoReflect.Descriptor instead.

func (*MsgPurchaseBeaconStateStorage) GetBeaconId

func (x *MsgPurchaseBeaconStateStorage) GetBeaconId() uint64

func (*MsgPurchaseBeaconStateStorage) GetNumber

func (x *MsgPurchaseBeaconStateStorage) GetNumber() uint64

func (*MsgPurchaseBeaconStateStorage) GetOwner

func (x *MsgPurchaseBeaconStateStorage) GetOwner() string

func (*MsgPurchaseBeaconStateStorage) ProtoMessage

func (*MsgPurchaseBeaconStateStorage) ProtoMessage()

func (*MsgPurchaseBeaconStateStorage) ProtoReflect

func (*MsgPurchaseBeaconStateStorage) Reset

func (x *MsgPurchaseBeaconStateStorage) Reset()

func (*MsgPurchaseBeaconStateStorage) String

type MsgPurchaseBeaconStateStorageResponse

type MsgPurchaseBeaconStateStorageResponse struct {

	// beacon_id is the id of the beacon the storage is being purchased for
	BeaconId uint64 `protobuf:"varint,1,opt,name=beacon_id,json=beaconId,proto3" json:"beacon_id,omitempty"`
	// number_purchased is the number of state storage spaces purchased
	NumberPurchased uint64 `protobuf:"varint,2,opt,name=number_purchased,json=numberPurchased,proto3" json:"number_purchased,omitempty"`
	// num_can_purchase is the number of remaining slots available for purchase
	NumCanPurchase uint64 `protobuf:"varint,3,opt,name=num_can_purchase,json=numCanPurchase,proto3" json:"num_can_purchase,omitempty"`
	// contains filtered or unexported fields
}

MsgPurchaseBeaconStateStorageResponse defines the Msg/PurchaseBeaconStateStorage response type.

func (*MsgPurchaseBeaconStateStorageResponse) Descriptor deprecated

func (*MsgPurchaseBeaconStateStorageResponse) Descriptor() ([]byte, []int)

Deprecated: Use MsgPurchaseBeaconStateStorageResponse.ProtoReflect.Descriptor instead.

func (*MsgPurchaseBeaconStateStorageResponse) GetBeaconId

func (*MsgPurchaseBeaconStateStorageResponse) GetNumCanPurchase

func (x *MsgPurchaseBeaconStateStorageResponse) GetNumCanPurchase() uint64

func (*MsgPurchaseBeaconStateStorageResponse) GetNumberPurchased

func (x *MsgPurchaseBeaconStateStorageResponse) GetNumberPurchased() uint64

func (*MsgPurchaseBeaconStateStorageResponse) ProtoMessage

func (*MsgPurchaseBeaconStateStorageResponse) ProtoMessage()

func (*MsgPurchaseBeaconStateStorageResponse) ProtoReflect

func (*MsgPurchaseBeaconStateStorageResponse) Reset

func (*MsgPurchaseBeaconStateStorageResponse) String

type MsgRecordBeaconTimestamp

type MsgRecordBeaconTimestamp struct {

	// beacon_id is the id of the beacon the timestamp is being submitted for
	BeaconId uint64 `protobuf:"varint,1,opt,name=beacon_id,json=beaconId,proto3" json:"beacon_id,omitempty"`
	// hash is the hash or data being submitted
	Hash string `protobuf:"bytes,2,opt,name=hash,proto3" json:"hash,omitempty"`
	// submit_time is a unix epoch value of the submission time
	SubmitTime uint64 `protobuf:"varint,3,opt,name=submit_time,json=submitTime,proto3" json:"submit_time,omitempty"`
	// owner is the address of the owner of the beacon
	Owner string `protobuf:"bytes,4,opt,name=owner,proto3" json:"owner,omitempty"`
	// contains filtered or unexported fields
}

MsgRecordBeaconTimestamp represents a message to record a timestamp for a registered beacon

func (*MsgRecordBeaconTimestamp) Descriptor deprecated

func (*MsgRecordBeaconTimestamp) Descriptor() ([]byte, []int)

Deprecated: Use MsgRecordBeaconTimestamp.ProtoReflect.Descriptor instead.

func (*MsgRecordBeaconTimestamp) GetBeaconId

func (x *MsgRecordBeaconTimestamp) GetBeaconId() uint64

func (*MsgRecordBeaconTimestamp) GetHash

func (x *MsgRecordBeaconTimestamp) GetHash() string

func (*MsgRecordBeaconTimestamp) GetOwner

func (x *MsgRecordBeaconTimestamp) GetOwner() string

func (*MsgRecordBeaconTimestamp) GetSubmitTime

func (x *MsgRecordBeaconTimestamp) GetSubmitTime() uint64

func (*MsgRecordBeaconTimestamp) ProtoMessage

func (*MsgRecordBeaconTimestamp) ProtoMessage()

func (*MsgRecordBeaconTimestamp) ProtoReflect

func (x *MsgRecordBeaconTimestamp) ProtoReflect() protoreflect.Message

func (*MsgRecordBeaconTimestamp) Reset

func (x *MsgRecordBeaconTimestamp) Reset()

func (*MsgRecordBeaconTimestamp) String

func (x *MsgRecordBeaconTimestamp) String() string

type MsgRecordBeaconTimestampResponse

type MsgRecordBeaconTimestampResponse struct {

	// beacon_id is the id of the beacon
	BeaconId uint64 `protobuf:"varint,1,opt,name=beacon_id,json=beaconId,proto3" json:"beacon_id,omitempty"`
	// timestamp_id is the id of the new timestamp
	TimestampId uint64 `protobuf:"varint,2,opt,name=timestamp_id,json=timestampId,proto3" json:"timestamp_id,omitempty"`
	// contains filtered or unexported fields
}

MsgRecordBeaconTimestampResponse defines the Msg/RecordBeacon response type.

func (*MsgRecordBeaconTimestampResponse) Descriptor deprecated

func (*MsgRecordBeaconTimestampResponse) Descriptor() ([]byte, []int)

Deprecated: Use MsgRecordBeaconTimestampResponse.ProtoReflect.Descriptor instead.

func (*MsgRecordBeaconTimestampResponse) GetBeaconId

func (x *MsgRecordBeaconTimestampResponse) GetBeaconId() uint64

func (*MsgRecordBeaconTimestampResponse) GetTimestampId

func (x *MsgRecordBeaconTimestampResponse) GetTimestampId() uint64

func (*MsgRecordBeaconTimestampResponse) ProtoMessage

func (*MsgRecordBeaconTimestampResponse) ProtoMessage()

func (*MsgRecordBeaconTimestampResponse) ProtoReflect

func (*MsgRecordBeaconTimestampResponse) Reset

func (*MsgRecordBeaconTimestampResponse) String

type MsgRegisterBeacon

type MsgRegisterBeacon struct {

	// moniker is a short identifier for a beacon
	Moniker string `protobuf:"bytes,1,opt,name=moniker,proto3" json:"moniker,omitempty"`
	// name is a long name for a beacon
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// owner is the address of the owner of the beacon
	Owner string `protobuf:"bytes,3,opt,name=owner,proto3" json:"owner,omitempty"`
	// contains filtered or unexported fields
}

MsgRegisterBeacon represents a message to register a new beacon

func (*MsgRegisterBeacon) Descriptor deprecated

func (*MsgRegisterBeacon) Descriptor() ([]byte, []int)

Deprecated: Use MsgRegisterBeacon.ProtoReflect.Descriptor instead.

func (*MsgRegisterBeacon) GetMoniker

func (x *MsgRegisterBeacon) GetMoniker() string

func (*MsgRegisterBeacon) GetName

func (x *MsgRegisterBeacon) GetName() string

func (*MsgRegisterBeacon) GetOwner

func (x *MsgRegisterBeacon) GetOwner() string

func (*MsgRegisterBeacon) ProtoMessage

func (*MsgRegisterBeacon) ProtoMessage()

func (*MsgRegisterBeacon) ProtoReflect

func (x *MsgRegisterBeacon) ProtoReflect() protoreflect.Message

func (*MsgRegisterBeacon) Reset

func (x *MsgRegisterBeacon) Reset()

func (*MsgRegisterBeacon) String

func (x *MsgRegisterBeacon) String() string

type MsgRegisterBeaconResponse

type MsgRegisterBeaconResponse struct {

	// beacon_id is the id of the new beacon
	BeaconId uint64 `protobuf:"varint,1,opt,name=beacon_id,json=beaconId,proto3" json:"beacon_id,omitempty"`
	// contains filtered or unexported fields
}

MsgRegisterBeaconResponse defines the Msg/RegisterBeacon response type.

func (*MsgRegisterBeaconResponse) Descriptor deprecated

func (*MsgRegisterBeaconResponse) Descriptor() ([]byte, []int)

Deprecated: Use MsgRegisterBeaconResponse.ProtoReflect.Descriptor instead.

func (*MsgRegisterBeaconResponse) GetBeaconId

func (x *MsgRegisterBeaconResponse) GetBeaconId() uint64

func (*MsgRegisterBeaconResponse) ProtoMessage

func (*MsgRegisterBeaconResponse) ProtoMessage()

func (*MsgRegisterBeaconResponse) ProtoReflect

func (*MsgRegisterBeaconResponse) Reset

func (x *MsgRegisterBeaconResponse) Reset()

func (*MsgRegisterBeaconResponse) String

func (x *MsgRegisterBeaconResponse) String() string

type MsgServer

type MsgServer interface {
	// RegisterBeacon defines a method to register a new beacon
	RegisterBeacon(context.Context, *MsgRegisterBeacon) (*MsgRegisterBeaconResponse, error)
	// RecordBeaconTimestamp defines a method to record a timestamp for a registered beacon
	RecordBeaconTimestamp(context.Context, *MsgRecordBeaconTimestamp) (*MsgRecordBeaconTimestampResponse, error)
	// PurchaseBeaconStateStorage defines the method to purchase more state storage
	PurchaseBeaconStateStorage(context.Context, *MsgPurchaseBeaconStateStorage) (*MsgPurchaseBeaconStateStorageResponse, error)
	// UpdateParams defines an operation for updating the x/beacon module
	// parameters.
	// Since: cosmos-sdk 0.47
	UpdateParams(context.Context, *MsgUpdateParams) (*MsgUpdateParamsResponse, error)
	// contains filtered or unexported methods
}

MsgServer is the server API for Msg service. All implementations must embed UnimplementedMsgServer for forward compatibility

type MsgUpdateParams

type MsgUpdateParams struct {

	// authority is the address that controls the module (defaults to x/gov unless overwritten).
	Authority string `protobuf:"bytes,1,opt,name=authority,proto3" json:"authority,omitempty"`
	// params defines the x/beacon parameters to update.
	//
	// NOTE: All parameters must be supplied.
	Params *Params `protobuf:"bytes,2,opt,name=params,proto3" json:"params,omitempty"`
	// contains filtered or unexported fields
}

MsgUpdateParams is the Msg/UpdateParams request type.

Since: cosmos-sdk 0.47

func (*MsgUpdateParams) Descriptor deprecated

func (*MsgUpdateParams) Descriptor() ([]byte, []int)

Deprecated: Use MsgUpdateParams.ProtoReflect.Descriptor instead.

func (*MsgUpdateParams) GetAuthority

func (x *MsgUpdateParams) GetAuthority() string

func (*MsgUpdateParams) GetParams

func (x *MsgUpdateParams) GetParams() *Params

func (*MsgUpdateParams) ProtoMessage

func (*MsgUpdateParams) ProtoMessage()

func (*MsgUpdateParams) ProtoReflect

func (x *MsgUpdateParams) ProtoReflect() protoreflect.Message

func (*MsgUpdateParams) Reset

func (x *MsgUpdateParams) Reset()

func (*MsgUpdateParams) String

func (x *MsgUpdateParams) String() string

type MsgUpdateParamsResponse

type MsgUpdateParamsResponse struct {
	// contains filtered or unexported fields
}

MsgUpdateParamsResponse defines the response structure for executing a MsgUpdateParams message.

Since: cosmos-sdk 0.47

func (*MsgUpdateParamsResponse) Descriptor deprecated

func (*MsgUpdateParamsResponse) Descriptor() ([]byte, []int)

Deprecated: Use MsgUpdateParamsResponse.ProtoReflect.Descriptor instead.

func (*MsgUpdateParamsResponse) ProtoMessage

func (*MsgUpdateParamsResponse) ProtoMessage()

func (*MsgUpdateParamsResponse) ProtoReflect

func (x *MsgUpdateParamsResponse) ProtoReflect() protoreflect.Message

func (*MsgUpdateParamsResponse) Reset

func (x *MsgUpdateParamsResponse) Reset()

func (*MsgUpdateParamsResponse) String

func (x *MsgUpdateParamsResponse) String() string

type Params

type Params struct {

	// fee_register is the cost to register a beacon
	FeeRegister uint64 `protobuf:"varint,1,opt,name=fee_register,json=feeRegister,proto3" json:"fee_register,omitempty"`
	// fee_record is the cost to record a single timestamp
	FeeRecord uint64 `protobuf:"varint,2,opt,name=fee_record,json=feeRecord,proto3" json:"fee_record,omitempty"`
	// fee_purchase_storage is the cost to purchase a single additional unit of in-state storage
	FeePurchaseStorage uint64 `protobuf:"varint,3,opt,name=fee_purchase_storage,json=feePurchaseStorage,proto3" json:"fee_purchase_storage,omitempty"`
	// denom is the expected denomination to pay for fees, e.g. nund
	Denom string `protobuf:"bytes,4,opt,name=denom,proto3" json:"denom,omitempty"`
	// default_storage_limit is the default in-state storage limit for all new beacons
	DefaultStorageLimit uint64 `protobuf:"varint,5,opt,name=default_storage_limit,json=defaultStorageLimit,proto3" json:"default_storage_limit,omitempty"`
	// max_storage_limit is the maximum in-state storage slots any one beacon can have
	MaxStorageLimit uint64 `protobuf:"varint,6,opt,name=max_storage_limit,json=maxStorageLimit,proto3" json:"max_storage_limit,omitempty"`
	// contains filtered or unexported fields
}

Params defines the parameters for the beacon module.

func (*Params) Descriptor deprecated

func (*Params) Descriptor() ([]byte, []int)

Deprecated: Use Params.ProtoReflect.Descriptor instead.

func (*Params) GetDefaultStorageLimit

func (x *Params) GetDefaultStorageLimit() uint64

func (*Params) GetDenom

func (x *Params) GetDenom() string

func (*Params) GetFeePurchaseStorage

func (x *Params) GetFeePurchaseStorage() uint64

func (*Params) GetFeeRecord

func (x *Params) GetFeeRecord() uint64

func (*Params) GetFeeRegister

func (x *Params) GetFeeRegister() uint64

func (*Params) GetMaxStorageLimit

func (x *Params) GetMaxStorageLimit() uint64

func (*Params) ProtoMessage

func (*Params) ProtoMessage()

func (*Params) ProtoReflect

func (x *Params) ProtoReflect() protoreflect.Message

func (*Params) Reset

func (x *Params) Reset()

func (*Params) String

func (x *Params) String() string

type QueryBeaconRequest

type QueryBeaconRequest struct {

	// beacon_id is the id of the beacon to query for
	BeaconId uint64 `protobuf:"varint,1,opt,name=beacon_id,json=beaconId,proto3" json:"beacon_id,omitempty"`
	// contains filtered or unexported fields
}

QueryBeaconRequest is the request type for the Query/Beacon RPC method

func (*QueryBeaconRequest) Descriptor deprecated

func (*QueryBeaconRequest) Descriptor() ([]byte, []int)

Deprecated: Use QueryBeaconRequest.ProtoReflect.Descriptor instead.

func (*QueryBeaconRequest) GetBeaconId

func (x *QueryBeaconRequest) GetBeaconId() uint64

func (*QueryBeaconRequest) ProtoMessage

func (*QueryBeaconRequest) ProtoMessage()

func (*QueryBeaconRequest) ProtoReflect

func (x *QueryBeaconRequest) ProtoReflect() protoreflect.Message

func (*QueryBeaconRequest) Reset

func (x *QueryBeaconRequest) Reset()

func (*QueryBeaconRequest) String

func (x *QueryBeaconRequest) String() string

type QueryBeaconResponse

type QueryBeaconResponse struct {
	Beacon *Beacon `protobuf:"bytes,1,opt,name=beacon,proto3" json:"beacon,omitempty"`
	// contains filtered or unexported fields
}

QueryBeaconResponse is the response type for the Query/Beacon RPC method

func (*QueryBeaconResponse) Descriptor deprecated

func (*QueryBeaconResponse) Descriptor() ([]byte, []int)

Deprecated: Use QueryBeaconResponse.ProtoReflect.Descriptor instead.

func (*QueryBeaconResponse) GetBeacon

func (x *QueryBeaconResponse) GetBeacon() *Beacon

func (*QueryBeaconResponse) ProtoMessage

func (*QueryBeaconResponse) ProtoMessage()

func (*QueryBeaconResponse) ProtoReflect

func (x *QueryBeaconResponse) ProtoReflect() protoreflect.Message

func (*QueryBeaconResponse) Reset

func (x *QueryBeaconResponse) Reset()

func (*QueryBeaconResponse) String

func (x *QueryBeaconResponse) String() string

type QueryBeaconStorageRequest

type QueryBeaconStorageRequest struct {

	// beacon_id is the id of the beacon to query for
	BeaconId uint64 `protobuf:"varint,1,opt,name=beacon_id,json=beaconId,proto3" json:"beacon_id,omitempty"`
	// contains filtered or unexported fields
}

QueryBeaconStorageRequest is the request type for the Query/BeaconStorage RPC method

func (*QueryBeaconStorageRequest) Descriptor deprecated

func (*QueryBeaconStorageRequest) Descriptor() ([]byte, []int)

Deprecated: Use QueryBeaconStorageRequest.ProtoReflect.Descriptor instead.

func (*QueryBeaconStorageRequest) GetBeaconId

func (x *QueryBeaconStorageRequest) GetBeaconId() uint64

func (*QueryBeaconStorageRequest) ProtoMessage

func (*QueryBeaconStorageRequest) ProtoMessage()

func (*QueryBeaconStorageRequest) ProtoReflect

func (*QueryBeaconStorageRequest) Reset

func (x *QueryBeaconStorageRequest) Reset()

func (*QueryBeaconStorageRequest) String

func (x *QueryBeaconStorageRequest) String() string

type QueryBeaconStorageResponse

type QueryBeaconStorageResponse struct {
	BeaconId uint64 `protobuf:"varint,1,opt,name=beacon_id,json=beaconId,proto3" json:"beacon_id,omitempty"`
	Owner    string `protobuf:"bytes,2,opt,name=owner,proto3" json:"owner,omitempty"`
	// current_limit is the current in-state storage limit for this beacon
	CurrentLimit uint64 `protobuf:"varint,3,opt,name=current_limit,json=currentLimit,proto3" json:"current_limit,omitempty"`
	// current_used is the number of in-state slots currently used
	CurrentUsed uint64 `protobuf:"varint,4,opt,name=current_used,json=currentUsed,proto3" json:"current_used,omitempty"`
	// max is the maximum possible slots a beacon can have, as defined by the beacon module params
	Max uint64 `protobuf:"varint,5,opt,name=max,proto3" json:"max,omitempty"`
	// max_purchasable is the maximum number a beacon can purchase without exceeding max
	MaxPurchasable uint64 `protobuf:"varint,6,opt,name=max_purchasable,json=maxPurchasable,proto3" json:"max_purchasable,omitempty"`
	// contains filtered or unexported fields
}

QueryBeaconStorageResponse is the response type for the Query/BeaconStorage RPC method

func (*QueryBeaconStorageResponse) Descriptor deprecated

func (*QueryBeaconStorageResponse) Descriptor() ([]byte, []int)

Deprecated: Use QueryBeaconStorageResponse.ProtoReflect.Descriptor instead.

func (*QueryBeaconStorageResponse) GetBeaconId

func (x *QueryBeaconStorageResponse) GetBeaconId() uint64

func (*QueryBeaconStorageResponse) GetCurrentLimit

func (x *QueryBeaconStorageResponse) GetCurrentLimit() uint64

func (*QueryBeaconStorageResponse) GetCurrentUsed

func (x *QueryBeaconStorageResponse) GetCurrentUsed() uint64

func (*QueryBeaconStorageResponse) GetMax

func (x *QueryBeaconStorageResponse) GetMax() uint64

func (*QueryBeaconStorageResponse) GetMaxPurchasable

func (x *QueryBeaconStorageResponse) GetMaxPurchasable() uint64

func (*QueryBeaconStorageResponse) GetOwner

func (x *QueryBeaconStorageResponse) GetOwner() string

func (*QueryBeaconStorageResponse) ProtoMessage

func (*QueryBeaconStorageResponse) ProtoMessage()

func (*QueryBeaconStorageResponse) ProtoReflect

func (*QueryBeaconStorageResponse) Reset

func (x *QueryBeaconStorageResponse) Reset()

func (*QueryBeaconStorageResponse) String

func (x *QueryBeaconStorageResponse) String() string

type QueryBeaconTimestampRequest

type QueryBeaconTimestampRequest struct {

	// beacon_id is the id of the beacon to query for
	BeaconId uint64 `protobuf:"varint,1,opt,name=beacon_id,json=beaconId,proto3" json:"beacon_id,omitempty"`
	// timestamp_id is the id of the timestamp to query for
	TimestampId uint64 `protobuf:"varint,2,opt,name=timestamp_id,json=timestampId,proto3" json:"timestamp_id,omitempty"`
	// contains filtered or unexported fields
}

QueryBeaconTimestampRequest is the request type for the Query/BeaconTimestamp RPC method

func (*QueryBeaconTimestampRequest) Descriptor deprecated

func (*QueryBeaconTimestampRequest) Descriptor() ([]byte, []int)

Deprecated: Use QueryBeaconTimestampRequest.ProtoReflect.Descriptor instead.

func (*QueryBeaconTimestampRequest) GetBeaconId

func (x *QueryBeaconTimestampRequest) GetBeaconId() uint64

func (*QueryBeaconTimestampRequest) GetTimestampId

func (x *QueryBeaconTimestampRequest) GetTimestampId() uint64

func (*QueryBeaconTimestampRequest) ProtoMessage

func (*QueryBeaconTimestampRequest) ProtoMessage()

func (*QueryBeaconTimestampRequest) ProtoReflect

func (*QueryBeaconTimestampRequest) Reset

func (x *QueryBeaconTimestampRequest) Reset()

func (*QueryBeaconTimestampRequest) String

func (x *QueryBeaconTimestampRequest) String() string

type QueryBeaconTimestampResponse

type QueryBeaconTimestampResponse struct {
	Timestamp *BeaconTimestamp `protobuf:"bytes,1,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
	BeaconId  uint64           `protobuf:"varint,2,opt,name=beacon_id,json=beaconId,proto3" json:"beacon_id,omitempty"`
	Owner     string           `protobuf:"bytes,3,opt,name=owner,proto3" json:"owner,omitempty"`
	// contains filtered or unexported fields
}

QueryBeaconTimestampResponse is the response type for the Query/BeaconTimestamp RPC method

func (*QueryBeaconTimestampResponse) Descriptor deprecated

func (*QueryBeaconTimestampResponse) Descriptor() ([]byte, []int)

Deprecated: Use QueryBeaconTimestampResponse.ProtoReflect.Descriptor instead.

func (*QueryBeaconTimestampResponse) GetBeaconId

func (x *QueryBeaconTimestampResponse) GetBeaconId() uint64

func (*QueryBeaconTimestampResponse) GetOwner

func (x *QueryBeaconTimestampResponse) GetOwner() string

func (*QueryBeaconTimestampResponse) GetTimestamp

func (x *QueryBeaconTimestampResponse) GetTimestamp() *BeaconTimestamp

func (*QueryBeaconTimestampResponse) ProtoMessage

func (*QueryBeaconTimestampResponse) ProtoMessage()

func (*QueryBeaconTimestampResponse) ProtoReflect

func (*QueryBeaconTimestampResponse) Reset

func (x *QueryBeaconTimestampResponse) Reset()

func (*QueryBeaconTimestampResponse) String

type QueryBeaconsFilteredRequest

type QueryBeaconsFilteredRequest struct {

	// moniker is the moniker of the beacon to search for
	Moniker string `protobuf:"bytes,1,opt,name=moniker,proto3" json:"moniker,omitempty"`
	// owner is an address to search for
	Owner string `protobuf:"bytes,2,opt,name=owner,proto3" json:"owner,omitempty"`
	// pagination defines an optional pagination for the request.
	Pagination *v1beta1.PageRequest `protobuf:"bytes,3,opt,name=pagination,proto3" json:"pagination,omitempty"`
	// contains filtered or unexported fields
}

QueryBeaconsFilteredRequest is the request type for the Query/BeaconsFiltered RPC method

func (*QueryBeaconsFilteredRequest) Descriptor deprecated

func (*QueryBeaconsFilteredRequest) Descriptor() ([]byte, []int)

Deprecated: Use QueryBeaconsFilteredRequest.ProtoReflect.Descriptor instead.

func (*QueryBeaconsFilteredRequest) GetMoniker

func (x *QueryBeaconsFilteredRequest) GetMoniker() string

func (*QueryBeaconsFilteredRequest) GetOwner

func (x *QueryBeaconsFilteredRequest) GetOwner() string

func (*QueryBeaconsFilteredRequest) GetPagination

func (x *QueryBeaconsFilteredRequest) GetPagination() *v1beta1.PageRequest

func (*QueryBeaconsFilteredRequest) ProtoMessage

func (*QueryBeaconsFilteredRequest) ProtoMessage()

func (*QueryBeaconsFilteredRequest) ProtoReflect

func (*QueryBeaconsFilteredRequest) Reset

func (x *QueryBeaconsFilteredRequest) Reset()

func (*QueryBeaconsFilteredRequest) String

func (x *QueryBeaconsFilteredRequest) String() string

type QueryBeaconsFilteredResponse

type QueryBeaconsFilteredResponse struct {
	Beacons []*Beacon `protobuf:"bytes,1,rep,name=beacons,proto3" json:"beacons,omitempty"`
	// pagination defines the pagination in the response.
	Pagination *v1beta1.PageResponse `protobuf:"bytes,2,opt,name=pagination,proto3" json:"pagination,omitempty"`
	// contains filtered or unexported fields
}

QueryBeaconsFilteredResponse is the response type for the Query/BeaconsFiltered RPC method

func (*QueryBeaconsFilteredResponse) Descriptor deprecated

func (*QueryBeaconsFilteredResponse) Descriptor() ([]byte, []int)

Deprecated: Use QueryBeaconsFilteredResponse.ProtoReflect.Descriptor instead.

func (*QueryBeaconsFilteredResponse) GetBeacons

func (x *QueryBeaconsFilteredResponse) GetBeacons() []*Beacon

func (*QueryBeaconsFilteredResponse) GetPagination

func (*QueryBeaconsFilteredResponse) ProtoMessage

func (*QueryBeaconsFilteredResponse) ProtoMessage()

func (*QueryBeaconsFilteredResponse) ProtoReflect

func (*QueryBeaconsFilteredResponse) Reset

func (x *QueryBeaconsFilteredResponse) Reset()

func (*QueryBeaconsFilteredResponse) String

type QueryClient

type QueryClient interface {
	// Params queries the parameters of x/beacon module.
	Params(ctx context.Context, in *QueryParamsRequest, opts ...grpc.CallOption) (*QueryParamsResponse, error)
	// Beacon queries the metadata of a beacon.
	Beacon(ctx context.Context, in *QueryBeaconRequest, opts ...grpc.CallOption) (*QueryBeaconResponse, error)
	// BeaconTimestamp queries a timestamp of a beacon
	BeaconTimestamp(ctx context.Context, in *QueryBeaconTimestampRequest, opts ...grpc.CallOption) (*QueryBeaconTimestampResponse, error)
	// BeaconsFiltered queries all beacon metadata for given search parameters
	BeaconsFiltered(ctx context.Context, in *QueryBeaconsFilteredRequest, opts ...grpc.CallOption) (*QueryBeaconsFilteredResponse, error)
	// BeaconStorage queries beacon storage for for given beacon ID
	BeaconStorage(ctx context.Context, in *QueryBeaconStorageRequest, opts ...grpc.CallOption) (*QueryBeaconStorageResponse, error)
}

QueryClient is the client API for Query service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewQueryClient

func NewQueryClient(cc grpc.ClientConnInterface) QueryClient

type QueryParamsRequest

type QueryParamsRequest struct {
	// contains filtered or unexported fields
}

QueryParamsRequest is the request type for the Query/Params RPC method

func (*QueryParamsRequest) Descriptor deprecated

func (*QueryParamsRequest) Descriptor() ([]byte, []int)

Deprecated: Use QueryParamsRequest.ProtoReflect.Descriptor instead.

func (*QueryParamsRequest) ProtoMessage

func (*QueryParamsRequest) ProtoMessage()

func (*QueryParamsRequest) ProtoReflect

func (x *QueryParamsRequest) ProtoReflect() protoreflect.Message

func (*QueryParamsRequest) Reset

func (x *QueryParamsRequest) Reset()

func (*QueryParamsRequest) String

func (x *QueryParamsRequest) String() string

type QueryParamsResponse

type QueryParamsResponse struct {
	Params *Params `protobuf:"bytes,1,opt,name=params,proto3" json:"params,omitempty"`
	// contains filtered or unexported fields
}

QueryParamsResponse is the response type for the Query/Params RPC method

func (*QueryParamsResponse) Descriptor deprecated

func (*QueryParamsResponse) Descriptor() ([]byte, []int)

Deprecated: Use QueryParamsResponse.ProtoReflect.Descriptor instead.

func (*QueryParamsResponse) GetParams

func (x *QueryParamsResponse) GetParams() *Params

func (*QueryParamsResponse) ProtoMessage

func (*QueryParamsResponse) ProtoMessage()

func (*QueryParamsResponse) ProtoReflect

func (x *QueryParamsResponse) ProtoReflect() protoreflect.Message

func (*QueryParamsResponse) Reset

func (x *QueryParamsResponse) Reset()

func (*QueryParamsResponse) String

func (x *QueryParamsResponse) String() string

type QueryServer

type QueryServer interface {
	// Params queries the parameters of x/beacon module.
	Params(context.Context, *QueryParamsRequest) (*QueryParamsResponse, error)
	// Beacon queries the metadata of a beacon.
	Beacon(context.Context, *QueryBeaconRequest) (*QueryBeaconResponse, error)
	// BeaconTimestamp queries a timestamp of a beacon
	BeaconTimestamp(context.Context, *QueryBeaconTimestampRequest) (*QueryBeaconTimestampResponse, error)
	// BeaconsFiltered queries all beacon metadata for given search parameters
	BeaconsFiltered(context.Context, *QueryBeaconsFilteredRequest) (*QueryBeaconsFilteredResponse, error)
	// BeaconStorage queries beacon storage for for given beacon ID
	BeaconStorage(context.Context, *QueryBeaconStorageRequest) (*QueryBeaconStorageResponse, error)
	// contains filtered or unexported methods
}

QueryServer is the server API for Query service. All implementations must embed UnimplementedQueryServer for forward compatibility

type UnimplementedMsgServer

type UnimplementedMsgServer struct {
}

UnimplementedMsgServer must be embedded to have forward compatible implementations.

func (UnimplementedMsgServer) RegisterBeacon

func (UnimplementedMsgServer) UpdateParams

type UnimplementedQueryServer

type UnimplementedQueryServer struct {
}

UnimplementedQueryServer must be embedded to have forward compatible implementations.

func (UnimplementedQueryServer) Beacon

func (UnimplementedQueryServer) Params

type UnsafeMsgServer

type UnsafeMsgServer interface {
	// contains filtered or unexported methods
}

UnsafeMsgServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to MsgServer will result in compilation errors.

type UnsafeQueryServer

type UnsafeQueryServer interface {
	// contains filtered or unexported methods
}

UnsafeQueryServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to QueryServer will result in compilation errors.

Jump to